@@ -39,6 +39,7 @@ const MapView = imports.mapView;
 const PlaceEntry = imports.placeEntry;
 const PlaceStore = imports.placeStore;
 const PrintOperation = imports.printOperation;
+const ShapeLayer = imports.shapeLayer;
 const Sidebar = imports.sidebar;
 const Utils = imports.utils;
 const ZoomControl = imports.zoomControl;
@@ -47,6 +48,29 @@ const _CONFIGURE_ID_TIMEOUT = 100; // msecs
 const _WINDOW_MIN_WIDTH = 600;
 const _WINDOW_MIN_HEIGHT = 500;
 
+const ShapeLayerFileChooser = new Lang.Class({
+    Name: 'ShapeLayerFileChooser',
+    Extends: Gtk.FileChooserDialog,
+    Template: 'resource:///org/gnome/Maps/ui/shape-layer-file-chooser.ui',
+
+    _init: function(params) {
+        this.parent(params);
+        let allFilter = new Gtk.FileFilter();
+        allFilter.set_name(_("All Layer Files"));
+        this.add_filter(allFilter);
+        this.set_filter(allFilter);
+
+        ShapeLayer.SUPPORTED_TYPES.forEach((function(layerClass) {
+            let filter = new Gtk.FileFilter();
+            [filter, allFilter].forEach(function(f) {
+                layerClass.mimeTypes.forEach(f.add_mime_type.bind(f));
+            });
+            filter.set_name(layerClass.displayName);
+            this.add_filter(filter);
+        }).bind(this));
+    }
+});
+
 const MainWindow = new Lang.Class({
     Name: 'MainWindow',
     Extends: Gtk.ApplicationWindow,
@@ -176,10 +200,13 @@ const MainWindow = new Lang.Class({
                 state: ['b', false],
                 onActivate: this._onMapTypeMenuActivate.bind(this)
             },
-            'map-type': {
-                paramType: 's',
-                state: ['s', 'STREET'],
-                onActivate: this._onMapTypeActivate.bind(this)
+            'switch-to-street-view': {
+                accels: ['<Primary>1', '<Primary>KP_1'],
+                onActivate: this._onStreetViewActivate.bind(this)
+            },
+            'switch-to-aearial-view': {
+                accels: ['<Primary>2', '<Primary>KP_2'],
+                onActivate: this._onAerialViewActivate.bind(this)
             },
             'goto-user-location': {
                 accels: ['<Primary>L'],
@@ -191,7 +218,7 @@ const MainWindow = new Lang.Class({
                 onChangeState: this._onToggleSidebarChangeState.bind(this)
             },
             'zoom-in': {
-                accels: ['plus', '<Primary>plus', 'KP_Add', '<Primary>KP_Add', 'equal'],
+                accels: ['plus', '<Primary>plus', 'KP_Add', '<Primary>KP_Add', 'equal', '<Primary>equal'],
                 onActivate: this._mapView.view.zoom_in.bind(this._mapView.view)
             },
             'zoom-out': {
@@ -209,6 +236,10 @@ const MainWindow = new Lang.Class({
             'print-route': {
                 accels: ['<Primary>P'],
                 onActivate: this._printRouteActivate.bind(this)
+            },
+            'open-shape-layer': {
+                accels: ['<Primary>O'],
+                onActivate: this._onOpenShapeLayer.bind(this)
             }
         });
     },
@@ -411,10 +442,14 @@ const MainWindow = new Lang.Class({
         action.set_state(GLib.Variant.new('b', !state));
     },
 
-    _onMapTypeActivate: function(action, value) {
-        action.set_state(value);
-        let [mapType, len] = value.get_string();
-        this._mapView.setMapType(MapView.MapType[mapType]);
+    _onStreetViewActivate: function() {
+        this._mapView.setMapType(MapView.MapType.STREET);
+        this.layersPopover.setMapType(MapView.MapType.STREET);
+    },
+
+    _onAerialViewActivate: function() {
+        this._mapView.setMapType(MapView.MapType.AERIAL);
+        this.layersPopover.setMapType(MapView.MapType.AERIAL);
     },
 
     _onToggleSidebarChangeState: function(action, variant) {
@@ -457,6 +492,21 @@ const MainWindow = new Lang.Class({
                             aboutDialog.destroy.bind(aboutDialog));
     },
 
+    _onOpenShapeLayer: function() {
+        let fileChooser = new ShapeLayerFileChooser({
+            transient_for: this,
+        });
+
+        fileChooser.connect('response', (function(widget, response) {
+            if (response === Gtk.ResponseType.OK) {
+                this._mapView.openShapeLayers(fileChooser.get_files());
+                this.layersPopover.popdown();
+            }
+            fileChooser.destroy();
+        }).bind(this));
+        fileChooser.show();
+    },
+
     markBusy: function() {
         if (this._busySignalId !== 0)
             return;
