@@ -183,7 +183,7 @@ const OSM_FIELDS = [
         tag: 'religion',
         type: EditFieldType.COMBO,
         options: [['animist', _("Animism")],
-                  ['bahai', _("Bahá'í")],
+                  ['bahai', _("Bahá’í")],
                   ['buddhist', _("Buddhism")],
                   ['caodaism', _("Caodaism")],
                   ['christian', _("Christianity")],
@@ -211,6 +211,12 @@ const OSM_FIELDS = [
         type: EditFieldType.COMBO,
         options: [['yes', _("Yes")],
                   ['no', _("No")]]
+    },
+    {
+        name: _("Note"),
+        tag: 'note',
+        type: EditFieldType.TEXT,
+        hint: _("Information used to inform other mappers about non-obvious information about an element, the author’s intent when creating it, or hints for further improvement.")
     }];
 
 const OSMEditAddress = new Lang.Class({
